@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Logout Handler
 #
-# $Id: lonlogout.pm,v 1.22 2006/11/23 01:49:41 albertel Exp $
+# $Id: lonlogout.pm,v 1.24 2007/01/12 15:54:12 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -91,9 +91,13 @@ sub handler {
 					   'li' => 'log in again',
 					   'pe' => 'Please either',
 					   'or' => 'or');
-	my $login_url = '/adm/'.($env{'request.sso.login'} ? 'roles' 
-                                                           : 'login');
-	
+        my $relogin_server;
+        if ($env{'request.sso.reloginserver'}) {
+            $relogin_server = $env{'request.sso.reloginserver'};
+        }
+	my $login_url = $relogin_server.'/adm/'.
+                        ($env{'request.sso.login'} ? 'roles': 'login');
+ 
 	$relogmessage=(<<ENDRELOG);
 	<h1>$lt{'gb'}!</h1>
 	    $lt{'pe'} <a href="javascript:self.close();">$lt{'cw'}</a> $lt{'or'}
