@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # User Roles Screen
 #
-# $Id: lonroles.pm,v 1.173 2006/12/11 21:56:53 albertel Exp $
+# $Id: lonroles.pm,v 1.174 2006/12/14 20:49:23 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -407,10 +407,17 @@ ENDHEADER
 # --------------------------------------------------------------- Error Header?
     if ($error) {
 	$r->print("<h1>LON-CAPA Access Control</h1>");
-        $r->print("<!-- LONCAPAACCESSCONTROLERRORSCREEN --><hr /><pre>Access  : ".
-                  Apache::lonnet::plaintext($priv)."\n");
-        $r->print("Resource: ".&Apache::lonenc::check_encrypt($fn)."\n");
-        $r->print("Action  : $msg\n</pre><hr />");
+	$r->print("<!-- LONCAPAACCESSCONTROLERRORSCREEN --><hr /><pre>");
+	if ($priv ne '') {
+	    $r->print("Access  : ".&Apache::lonnet::plaintext($priv)."\n");
+	}
+	if ($fn ne '') {
+	    $r->print("Resource: ".&Apache::lonenc::check_encrypt($fn)."\n");
+	}
+	if ($msg ne '') {
+	    $r->print("Action  : $msg\n");
+	}
+	$r->print("</pre><hr />");
 	my $url=$fn;
 	my $last;
 	if (tie(my %hash,'GDBM_File',$env{'request.course.fn'}.'_symb.db',
