@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # definition of tags that give a structure to a document
 #
-# $Id: bridgetask.pm,v 1.224 2007/01/26 19:06:37 albertel Exp $
+# $Id: bridgetask.pm,v 1.224.2.2 2007/03/26 23:33:26 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -2322,8 +2322,11 @@ sub end_Dimension {
 		    }
 		}
 		# puts the results at the end of the dimension
-		$result .= $dim_info;
-
+		if ($result =~m{<QuestionGradeInfo\s*/>}) {
+		    $result=~s{<QuestionGradeInfo\s*/>}{$dim_info};
+		} else {
+		    $result .= $dim_info;
+		}
 		# puts the results at the beginning of the dimension
 		# my $internal_location=&internal_location($dim);
 		# $result=~s/\Q$internal_location\E/$dim_info/;
@@ -2833,11 +2836,13 @@ sub proctor_validation_screen {
 	    .'</font></p>';
     }
     if (!$env{'form.proctordomain'}) { $env{'form.proctordomain'}=$domain; }
+    my $uri = &Apache::lonenc::check_encrypt($env{'request.uri'});
+    $uri = &HTML::Entities::encode($uri,'<>&"');
     my $result= (<<ENDCHECKOUT);
 <h2>Proctor Validation</h2>
     <p>Your room's proctor needs to validate your access to this resource.</p>
     $msg
-<form name="checkout" method="post" action="$env{'request.uri'}">
+<form name="checkout" method="post" action="$uri">
 <input type="hidden" name="validate" value="yes" />
 <input type="hidden" name="submitted" value="yes" />
 <table>
