@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # The LON-CAPA Homework handler
 #
-# $Id: lonhomework.pm,v 1.262 2006/11/30 01:14:17 banghart Exp $
+# $Id: lonhomework.pm,v 1.263 2006/12/13 22:48:07 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -753,13 +753,20 @@ sub analyze {
 	    if ($analyze{$part.'.type'} eq 'numericalresponse'	||
 		$analyze{$part.'.type'} eq 'stringresponse'	||
 		$analyze{$part.'.type'} eq 'formularesponse'   ) {
-		my $concatanswer=join("\0",@{ $analyze{$part.'.answer'} });
-		if (($concatanswer eq '') || ($concatanswer=~/^\@/)) {
-		    @{$analyze{$part.'.answer'}}=('<font color="red">'.&mt('Error').'</font>');
+		foreach my $name (keys(%{ $analyze{$part.'.answer'} })) {
+		    my $i=0;
+		    foreach my $answer_part (@{ $analyze{$part.'.answer'}{$name} }) {
+			push( @{ $overall{$part.'.answer'}[$i] },
+			      $answer_part);
+			my $concatanswer= join("\0",@{ $answer_part });
+			if (($concatanswer eq '') || ($concatanswer=~/^\@/)) {
+			    $answer_part = ['<font color="red">'.&mt('Error').'</font>'];
+			}
+			$seedexample{join("\0",$part,$i,@{$answer_part})}=
+			    $thisseed;
+			$i++;
+		    }
 		}
-		push( @{ $overall{$part.'.answer'} },
-		      [@{ $analyze{$part.'.answer'} }]);
-                $seedexample{join("\0",@{ $analyze{$part.'.answer'}})}=$thisseed;
 	    }
 	}
     }
@@ -768,21 +775,27 @@ sub analyze {
     $request->print('<hr />'.&mt('List of possible answers').': ');
     foreach my $part (sort(keys(%allparts))) {
 	if (defined(@{ $overall{$part.'.answer'} })) {
-	    my $num_cols=scalar(@{ $overall{$part.'.answer'}->[0] });
-	    $request->print('<table class="thinborder"><tr><th colspan="'.($num_cols+1).'">'.&mt('Part').' '.$part.'</th></tr>');
-	    my %frequency;
-	    foreach my $answer (sort {$a->[0] <=> $b->[0]} (@{ $overall{$part.'.answer'} })) {
-		$frequency{join("\0",@{ $answer })}++;
+	    for (my $i=0;$i<scalar(@{ $overall{$part.'.answer'} });$i++) {
+		my $num_cols=scalar(@{ $overall{$part.'.answer'}[$i][0] });
+		$request->print('<table class="thinborder"><tr><th colspan="'.($num_cols+1).'">'.&mt('Part').' '.$part);
+		if (scalar(@{ $overall{$part.'.answer'} }) > 1) {
+		    $request->print(&mt(' Answer [_1]',$i+1));
+		}
+		$request->print('</th></tr>');
+		my %frequency;
+		foreach my $answer (sort {$a->[0] <=> $b->[0]} (@{ $overall{$part.'.answer'}[$i] })) {
+		    $frequency{join("\0",@{ $answer })}++;
+		}
+		$request->print('<tr><th colspan="'.($num_cols).'">'.&mt('Answer').'</th><th>'.&mt('Frequency').'<br />('
+				.&mt('click for example').')</th></tr>');
+		foreach my $answer (sort {(split("\0",$a))[0] <=> (split("\0",$b))[0]} (keys(%frequency))) {
+		    $request->print('<tr><td class="center">'.
+				    join('</td><td class="center">',split("\0",$answer)).
+				    '</td><td class="center"><a href="'.$request->uri.'?rndseed='.$seedexample{join("\0",$part,$i,$answer)}.'">'.$frequency{$answer}.
+				    '</a></td></tr>');
+		}
+		$request->print('</table>');
 	    }
-	    $request->print('<tr><th colspan="'.($num_cols).'">'.&mt('Answer').'</th><th>'.&mt('Frequency').'<br />('
-			    .&mt('click for example').')</th></tr>');
-	    foreach my $answer (sort {(split("\0",$a))[0] <=> (split("\0",$b))[0]} (keys(%frequency))) {
-		$request->print('<tr><td class="center">'.
-				join('</td><td class="center">',split("\0",$answer)).
-				'</td><td class="center"><a href="'.$request->uri.'?rndseed='.$seedexample{$answer}.'">'.$frequency{$answer}.
-				'</a></td></tr>');
-	    }
-	    $request->print('</table>');
 	} else {
 	    $request->print('<p>'.&mt('Response').' '.$part.' '.
 			    &mt('is not analyzable at this time').'</p>');
