@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # a pile of common html routines
 #
-# $Id: lonhtmlcommon.pm,v 1.155 2006/12/05 02:55:53 albertel Exp $
+# $Id: lonhtmlcommon.pm,v 1.156 2007/01/05 17:55:41 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1202,7 +1202,8 @@ Pushes a breadcrumb on the stack of crumbs.
 
 input: $breadcrumb, a hash reference.  The keys 'href','title', and 'text'
 are required.  If present the keys 'faq' and 'bug' will be used to provide
-links to the FAQ and bug sites.
+links to the FAQ and bug sites. If the key 'no_mt' is present the 'title' 
+and 'text' values won't be sent through &mt()
 
 returns: nothing    
 
@@ -1252,13 +1253,22 @@ returns: nothing
                      if (defined($_->{'target'}) && $_->{'target'} ne '') {
                          $result .= 'target="'.$_->{'target'}.'" ';
                      }
-                     $result .='title="'.&mt($_->{'title'}).'">'.
-                         &mt($_->{'text'}).'</a>';
+		     if ($_->{'no_mt'}) {
+			 $result .='title="'.$_->{'title'}.'">'.
+			     $_->{'text'}.'</a>';
+		     } else {
+			 $result .='title="'.&mt($_->{'title'}).'">'.
+			     &mt($_->{'text'}).'</a>';
+		     }
                      $result;
                      } @Crumbs
                  );
         $links .= '-&gt;' if ($links ne '');
-        $links .= '<b>'.&mt($last->{'text'}).'</b>';
+	if ($last->{'no_mt'}) {
+	    $links .= '<b>'.$last->{'text'}.'</b>';
+	} else {
+	    $links .= '<b>'.&mt($last->{'text'}).'</b>';
+	}
         #
         my $icons = '';
         $faq = $last->{'faq'} if (exists($last->{'faq'}));
