@@ -1,5 +1,5 @@
 #
-# $Id: lonwhatsnew.pm,v 1.66 2006/12/03 05:45:13 raeburn Exp $
+# $Id: lonwhatsnew.pm,v 1.67 2006/12/20 23:02:33 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -794,7 +794,8 @@ sub check_discussions {
     $$unread{$ressymb}{'lastpost'} = $resource->last_post_time();
     
     if ($countunread eq 'on') {
-	$$unread{$ressymb}{'unreadcount'} = $resource->unread_discussion();
+	$$unread{$ressymb}{'unreadcount'} = 
+                            $resource->discussion_info('unread');
     }
 }
 
