@@ -1,5 +1,5 @@
 #
-# $Id: studentcalc.pm,v 1.41 2006/10/02 17:04:33 raeburn Exp $
+# $Id: studentcalc.pm,v 1.42 2006/12/21 02:54:19 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -554,7 +554,7 @@ sub compute {
     }
     $self->initialize_safe_space();
     &Apache::assesscalc::initialize_package($self->{'name'},$self->{'domain'},
-                                            $navmap);
+                                            $navmap,$self);
     my %f = $self->formulas();
     #
     # Process the formulas list - 
