@@ -9,7 +9,7 @@
 #  and displays a page showing the results of the action.
 #
 #
-# $Id: loncfile.pm,v 1.79 2006/11/23 01:50:57 banghart Exp $
+# $Id: loncfile.pm,v 1.80 2006/12/20 22:41:08 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -72,9 +72,8 @@ use Apache::loncacc;
 use Apache::lonnet;
 use Apache::loncommon();
 use Apache::lonlocal;
-use lib '/home/httpd/lib/perl/';
-use LONCAPA;
- 
+use LONCAPA qw(:DEFAULT :match);
+
 
 my $DEBUG=0;
 my $r;				# Needs to be global for some stuff RF.
@@ -151,21 +150,21 @@ sub URLToPath {
     $Url=~ s/\/+/\//g;
     $Url=~ s/^http\:\/\/[^\/]+//;
     $Url=~ s/^\///;
-    $Url=~ s/(\~|priv\/)(\w+)\//\/home\/$2\/public_html\//;
+    $Url=~ s/(\~|priv\/)($match_username)\//\/home\/$2\/public_html\//;
     &Debug($r, "Returning $Url \n");
     return $Url;
 }
 
 sub url {
     my $fn=shift;
-    $fn=~s/^\/home\/(\w+)\/public\_html/\/priv\/$1/;
+    $fn=~s/^\/home\/($match_username)\/public\_html/\/priv\/$1/;
     $fn=&HTML::Entities::encode($fn,'<>"&');
     return $fn;
 }
 
 sub display {
     my $fn=shift;
-    $fn=~s-^/home/(\w+)/public_html-/priv/$1-;
+    $fn=~s-^/home/($match_username)/public_html-/priv/$1-;
     return '<tt>'.$fn.'</tt>';
 }
 
