@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Construction Space Directory Lister
 #
-# $Id: lonpubdir.pm,v 1.98 2006/12/06 22:22:39 albertel Exp $
+# $Id: lonpubdir.pm,v 1.101 2007/03/09 01:29:51 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -215,12 +215,13 @@ sub startpage {
 	$r->print($pagetitle);
     }
 
+    my $esc_thisdisfn = &Apache::loncommon::escape_single($thisdisfn);
     my $pubdirscript=(<<ENDPUBDIRSCRIPT);
 <script type="text/javascript">
-top.document.title = '$thisdisfn/ - LON-CAPA Construction Space';
+top.document.title = '$esc_thisdisfn/ - LON-CAPA Construction Space';
 // Store directory location for menu bar to find
 
-parent.lastknownpriv='/~$uname$thisdisfn/';
+parent.lastknownpriv='/~$uname$esc_thisdisfn/';
 
 // Confirmation dialogues
 
@@ -609,7 +610,6 @@ sub putresource {
 	$title = '<a href="/res/'.$targetdir.'/'.$filename.
 	    '.meta" target="cat">'.
 	    &getTitleString($targetdir.'/'.$filename).'</a>';
-	&Apache::lonnet::logthis("same $same meta $meta_same");
 	if ($same) {
 	    if (&Apache::lonnet::metadata($targetdir.'/'.$filename,'obsolete')) {
                 $pubstatus = 'obsolete';
@@ -716,7 +716,7 @@ sub create_pubselect {
 <input type="hidden" name="filename" value="/~'.
  &HTML::Entities::encode($uname.$thisdisfn.'/'.$filename,'<>&"').'" />
  <input type="hidden" name="dispfilename" value="'.
- &HTML::Entities::encode($filename).'"</form>';
+ &HTML::Entities::encode($filename).'" /></form>';
     $$numres ++;
 }
 
