@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Publication Handler
 #
-# $Id: lonpublisher.pm,v 1.216 2007/01/10 20:23:21 albertel Exp $
+# $Id: lonpublisher.pm,v 1.219 2007/02/01 02:38:05 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -183,17 +183,18 @@ sub metaeval {
 	if ($token->[0] eq 'S') {
 	    my $entry=$token->[1];
 	    my $unikey=$entry;
+	    next if ($entry =~ m/^(?:parameter|stores)_/);
 	    if (defined($token->[2]->{'package'})) { 
-		$unikey.='_package_'.$token->[2]->{'package'};
+		$unikey.="\0package\0".$token->[2]->{'package'};
 	    } 
 	    if (defined($token->[2]->{'part'})) { 
-		$unikey.='_'.$token->[2]->{'part'}; 
+		$unikey.="\0".$token->[2]->{'part'}; 
 	    }
 	    if (defined($token->[2]->{'id'})) { 
-		$unikey.='_'.$token->[2]->{'id'};
+		$unikey.="\0".$token->[2]->{'id'};
 	    } 
 	    if (defined($token->[2]->{'name'})) { 
-		$unikey.='_'.$token->[2]->{'name'}; 
+		$unikey.="\0".$token->[2]->{'name'}; 
 	    }
 	    foreach (@{$token->[3]}) {
 		$metadatafields{$unikey.'.'.$_}=$token->[2]->{$_};
@@ -471,7 +472,7 @@ sub set_allow {
 	($newurl !~ /^\#/)) {
 	$$allow{&absoluteurl($newurl,$target)}=1;
     }
-    return $return_url
+    return $return_url;
 }
 
 #########################################
@@ -507,18 +508,13 @@ sub get_subscribed_hosts {
     closedir(DIR);
     my $sh;
     if ( $sh=Apache::File->new("$target.subscription") ) {
-	&Apache::lonnet::logthis("opened $target.subscription");
 	while (my $subline=<$sh>) {
 	    if ($subline =~ /^($match_lonid):/) { 
                 if ($1 ne $Apache::lonnet::perlvar{'lonHostID'}) { 
                    push(@subscribed,$1);
 	        }
-            } else {
-		&Apache::lonnet::logthis("No Match for $subline");
 	    }
 	}
-    } else {
-	&Apache::lonnet::logthis("Unable to open $target.subscription");
     }
     return @subscribed;
 }
@@ -719,6 +715,7 @@ sub fix_ids_and_indices {
 		    ($lctag eq 'image')) {
 		    my $next_token=$parser[-1]->get_token();
 		    if ($next_token->[0] eq 'T') {
+                        $next_token->[1] =~ s/[\n\r\f]+//g;
 			$next_token->[1]=&set_allow(\%allow,$logfile,
 						    $target,$tag,
 						    $next_token->[1]);
@@ -1099,8 +1096,10 @@ sub publish {
 	if (($_=~/^parameter/) || ($_=~/^stores/)) {
 	    unless ($_=~/\.\w+$/) { 
 		unless ($oldparmstores{$_}) {
-		    print $logfile 'New: '.$_."\n";
-		    $chparms.=$_.' ';
+		    my $disp_key = $_;
+		    $disp_key =~ tr/\0/_/;
+		    print $logfile ('New: '.$disp_key."\n");
+		    $chparms .= $disp_key.' ';
 		}
 	    }
 	}
@@ -1115,16 +1114,18 @@ sub publish {
 	if (($_=~/^parameter/) || ($_=~/^stores/)) {
 	    unless (($metadatafields{$_.'.name'}) ||
 		    ($metadatafields{$_.'.package'}) || ($_=~/\.\w+$/)) {
-		print $logfile 'Obsolete: '.$_."\n";
-		$chparms.=$_.' ';
+		my $disp_key = $_;
+		$disp_key =~ tr/\0/_/;
+		print $logfile ('Obsolete: '.$disp_key."\n");
+		$chparms.=$disp_key.' ';
 	    }
 	}
     }
     if ($chparms) {
 	$scrout.='<p><b>'.&mt('Obsolete parameters or stored values').':</b> '.
-	    $chparms.'</p><h1><font color="red">'.&mt('Warning!').
-	    '</font></h1><p><font color="red" size="+1">'.
-	    &mt('If this resource is in active use, student performance data from the previous version may become inaccessible.').'</font></p><hr />';
+	    $chparms.'</p><h1><span class="LC_warning">'.&mt('Warning!').
+	    '</span></h1><p><span class="LC_warning">'.
+	    &mt('If this resource is in active use, student performance data from the previous version may become inaccessible.').'</span></p><hr />';
     }
 
 # ------------------------------------------------------- Now have all metadata
