@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Dynamic plot
 #
-# $Id: lonplot.pm,v 1.114 2006/09/06 19:26:15 albertel Exp $
+# $Id: lonplot.pm,v 1.115 2007/02/21 20:34:58 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -128,8 +128,8 @@ my $words_test     = sub {$_[0]=~s/\s+/ /g;$_[0]=~/^([\w~!\@\#\$\%^&\*\(\)-=_\+\
 ###################################################################
 my @gnuplot_edit_order = 
     qw/alttag bgcolor fgcolor height width font transparent grid samples 
-    border align texwidth texfont plotcolor plottype lmargin rmargin tmargin
-    bmargin major_ticscale minor_ticscale boxwidth gridlayer fillstyle
+    border align texwidth texfont plotcolor plottype gridtype lmargin rmargin
+    tmargin bmargin major_ticscale minor_ticscale boxwidth gridlayer fillstyle
     pattern solid/;
 
 my $margin_choices = ['default',0..20];
@@ -272,6 +272,13 @@ my %gnuplot_defaults =
 	 edit_type   => 'choice',
          choices     => ['Cartesian','Polar']
          },
+     gridtype     => {
+	 default     => 'Cartesian',
+	 test        => sub {$_[0]=~/^(Polar|Cartesian)$/},
+	 description => 'Grid type:',
+	 edit_type   => 'choice',
+         choices     => ['Cartesian','Polar']
+         },
      lmargin      => {
 	 default     => 'default',
 	 test        => sub {$_[0]=~/^(default|\d+)$/},
@@ -1113,12 +1120,18 @@ sub write_gnuplot_file {
 	$gnuplot_input .= "set output \"/home/httpd/perl/tmp/".
 	    &unescape($filename).".eps\"\n";
     }
-    # cartesian or polar?
+    # cartesian or polar plot?
     if (lc($Apache::lonplot::plot{'plottype'}) eq 'polar') {
         $gnuplot_input .= 'set polar'.$/;
     } else {
         # Assume Cartesian
     }
+    # cartesian or polar grid?
+    if (lc($Apache::lonplot::plot{'gridtype'}) eq 'polar') {
+        $gnuplot_input .= 'set grid polar'.$/;
+    } else {
+        # Assume Cartesian
+    }
     # solid or pattern for boxes?
     if (lc($Apache::lonplot::plot{'fillstyle'}) eq 'solid') {
         $gnuplot_input .= 'set style fill solid '.
