@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # routines for modyfing .sequence and .page files
 #
-# $Id: map.pm,v 1.4 2007/01/03 20:46:04 albertel Exp $
+# $Id: map.pm,v 1.5 2007/01/16 21:18:08 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -29,6 +29,7 @@
 package LONCAPA::map;
 
 use HTML::TokeParser;
+use HTML::Entities();
 use Apache::lonnet;
 use Apache::lonlocal;
 use File::Copy;
@@ -643,7 +644,7 @@ sub savemap {
 			$outstr.=' type="'.$comp[3].'"';
 		    }
 		    if ($comp[0] ne '') {
-			$outstr.=' title="'.$comp[0].'"';
+			$outstr.=' title="'.&HTML::Entities::encode($comp[0]).'"';
 		    }
 		    $outstr.=" />\n";
 		} elsif ($comp[$#comp] eq 'cond') {
